# Django-Futon

[![PyPI version](https://badge.fury.io/py/django-futon.svg)](https://badge.fury.io/py/django-futon)


## Description

A lightweight application for synchronising Django models between sites using
RESTful APIs.

TODO
